@@ -17,6 +17,6 @@ def get_my_ip():
 
 ip = str(get_my_ip())
 
-# main('makemigrations data')
-# main('migrate data')
-main('runserver',  ip + ':8000')
+main('__main__.py','makemigrations', 'data')
+main('__main__.py','migrate', 'data')
+main('__main__.py','runserver',ip + ':8000')
