@@ -5,9 +5,8 @@ from django.forms import ChoiceField
 from data.models.models import Calibration, Hardware, Accessory, Channel, HardwareConfig, \
     CalibrationConstants, DHT22, MCP3008, \
     ModProbe, PiPico, VEML7700, HardwareChannelTypes, Hub, Category, AccessoryType, SPIIo, SerialIo, PwmIo, I2cIo, \
-    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, HardwareIO
+    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, HardwareIO, PMSA0031
 
-from OpenHubAPI.data.models.models import PMSA0031
 
 
 class HubForm(forms.ModelForm):
