@@ -12,13 +12,12 @@ from rest_framework.response import Response
 from data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008Form, HardwareModProbeForm, \
     HardwarePiPicoForm, HardwareVEML7700Form, HardwareTypeForm, ChannelForm, HardwareConfigForm, AccessoryForm, \
     CalibrationForm, CalibrationConstantForm, HubForm, HardwareIOTypeForm, SPIIoForm, PwmIoForm, SerialIoForm, \
-    I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm
+    I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm, HardwarePMSA0031Form
 from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
     CalibrationConstants, Channel, Hub, HardwareIO
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
     CalibrationSerializer, HubSerializer, HardwareIOSerializer
 
-from OpenHubAPI.data.forms.forms import HardwarePMSA0031Form
 
 SPI = 'SPI'
 Serial = 'Serial'
